@@ -1,7 +1,4 @@
-import csv
-import shutil
 from enum import IntEnum
-from tempfile import NamedTemporaryFile
 
 CSV_HEADER = ['phone_number', 'user_address', 'contract_address',
               'current_balance', 'send_amount', 'timestamp']
